@@ -3,7 +3,7 @@ import time
 import os
 import logging
 import sys
-from . import Account, ComputeStatus
+from .account import Account, ComputeStatus
 
 logging.basicConfig(stream=sys.stdout, level=os.environ.get('LOGLEVEL', 'INFO').upper())
 
@@ -48,7 +48,6 @@ def login():
     try:
         _provision(account)
     except Exception as e:
-        raise e
         echo("An error occured when attempting to provision, please try again")
         logger.debug(e)
 
@@ -102,7 +101,6 @@ def create():
     try:
         _provision(account)
     except Exception as e:
-        raise e
         echo("An error occured when attempting to provision, please try again")
         logger.debug(e)
 
@@ -114,7 +112,6 @@ def _login(email, password):
     try:
         acc = Account.login(email, password)
     except Exception as e:
-        raise e
 
         if str(e) == "403":
             echo("Incorrect email/password")
